This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

Testsuite patch for PR testsuite/29093


The test gcc.dg/debug/dwarf2/dwarf-file1.c fails on systems that use
DWARF2 and also define HAVE_AS_DWARF2_DEBUG_LINE.  Those systems do not
put the string "File Entry:"  in the assembly language file.

They do put out the string ".file", so my idea is to check for either of
these strings in the test.  I think this should be OK unless systems
that don't define HAVE_AS_DWARF2_DEBUG_LINE might also put out ".file".
I don't see anyway for them to do that looking at the code but I don't
have a system where HAVE_AS_DWARF2_DEBUG_LINE isn't defined so I didn't
check it with an example.

I tested the change on IA64 Linux and the test passes there with this
change.  This is not a regression (the test never passed on platforms
which define HAVE_AS_DWARF2_DEBUG_LINE) but I believe testsuite changes
are allowed during regression fix period, correct?

If so, OK for checkin on the main line?

Steve Ellcey
sje@cup.hp.com


2006-10-11  Steve Ellcey  <sje@cup.hp.com>

	PR testsuite/29093
	* gcc.dg/debug/dwarf2/dwarf-file1.c: Check for ".file".


Index: gcc.dg/debug/dwarf2/dwarf-file1.c
===================================================================
--- gcc.dg/debug/dwarf2/dwarf-file1.c	(revision 117623)
+++ gcc.dg/debug/dwarf2/dwarf-file1.c	(working copy)
@@ -1,5 +1,9 @@
 /* { dg-do compile } */
 /* { dg-options "-O2 -gdwarf-2 -dA" } */
-/* { dg-final { scan-assembler "File Entry:" } } */
-/* Verify that a file entry is output for this file.  */
+/* { dg-final { scan-assembler "File Entry:|.file" } } */
+/* Verify that a file entry is output for this file.  Only systems that
+   do not define HAVE_AS_DWARF2_DEBUG_LINE will put out "File Entry:",
+   but systems that do define HAVE_AS_DWARF2_DEBUG_LINE will put out a
+   ".file" so we check for either.  */
+
 int bar = 3;


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]